@@ -9,9 +9,10 @@ import logging
 import socket
 import time
 
-import SoftLayer
 from SoftLayer.decoration import retry
+from SoftLayer.exceptions import SoftLayerError
 from SoftLayer.managers import ordering
+from SoftLayer.managers.ticket import TicketManager
 from SoftLayer import utils
 
 LOGGER = logging.getLogger(__name__)
@@ -77,19 +78,18 @@ class HardwareManager(utils.IdentifierMixin, object):
         # Get cancel reason
         reasons = self.get_cancellation_reasons()
         cancel_reason = reasons.get(reason, reasons['unneeded'])
-        ticket_mgr = SoftLayer.TicketManager(self.client)
+        ticket_mgr = TicketManager(self.client)
         mask = 'mask[id, hourlyBillingFlag, billingItem[id], openCancellationTicket[id], activeTransaction]'
         hw_billing = self.get_hardware(hardware_id, mask=mask)
 
         if 'activeTransaction' in hw_billing:
-            raise SoftLayer.SoftLayerError("Unable to cancel hardware with running transaction")
+            raise SoftLayerError("Unable to cancel hardware with running transaction")
 
         if 'billingItem' not in hw_billing:
             if utils.lookup(hw_billing, 'openCancellationTicket', 'id'):
-                raise SoftLayer.SoftLayerError("Ticket #%s already exists for this server" %
-                                               hw_billing['openCancellationTicket']['id'])
-            raise SoftLayer.SoftLayerError("Cannot locate billing for the server. "
-                                           "The server may already be cancelled.")
+                raise SoftLayerError("Ticket #%s already exists for this server" %
+                                     hw_billing['openCancellationTicket']['id'])
+            raise SoftLayerError("Cannot locate billing for the server. The server may already be cancelled.")
 
         billing_id = hw_billing['billingItem']['id']
 
@@ -297,7 +297,7 @@ class HardwareManager(utils.IdentifierMixin, object):
         """
         return self.hardware.bootToRescueLayer(id=hardware_id)
 
-    def change_port_speed(self, hardware_id, public, speed):
+    def change_port_speed(self, hardware_id, public, speed, redundant=None):
         """Allows you to change the port speed of a server's NICs.
 
         :param int hardware_id: The ID of the server
@@ -319,11 +319,11 @@ class HardwareManager(utils.IdentifierMixin, object):
         if public:
             return self.client.call('Hardware_Server',
                                     'setPublicNetworkInterfaceSpeed',
-                                    speed, id=hardware_id)
+                                    [speed, redundant], id=hardware_id)
         else:
             return self.client.call('Hardware_Server',
                                     'setPrivateNetworkInterfaceSpeed',
-                                    speed, id=hardware_id)
+                                    [speed, redundant], id=hardware_id)
 
     def place_order(self, **kwargs):
         """Places an order for a piece of hardware.
@@ -697,8 +697,35 @@ class HardwareManager(utils.IdentifierMixin, object):
         a_mask = "mask[allocation[amount]]"
         allotment = self.client.call('Hardware_Server', 'getBandwidthAllotmentDetail', id=instance_id, mask=a_mask)
         u_mask = "mask[amountIn,amountOut,type]"
-        useage = self.client.call('Hardware_Server', 'getBillingCycleBandwidthUsage', id=instance_id, mask=u_mask)
-        return {'allotment': allotment.get('allocation'), 'useage': useage}
+        usage = self.client.call('Hardware_Server', 'getBillingCycleBandwidthUsage', id=instance_id, mask=u_mask)
+        if allotment:
+            return {'allotment': allotment.get('allocation'), 'usage': usage}
+        return {'allotment': allotment, 'usage': usage}
+
+    def get_storage_details(self, instance_id, nas_type):
+        """Returns the hardware server attached network storage.
+
+        :param int instance_id: Id of the hardware server
+        :param nas_type: storage type.
+        """
+        mask = 'mask[id,username,capacityGb,notes,serviceResourceBackendIpAddress,' \
+               'allowedHardware[id,datacenter]]'
+        return self.hardware.getAttachedNetworkStorages(nas_type, mask=mask, id=instance_id)
+
+    def get_storage_credentials(self, instance_id):
+        """Returns the hardware server storage credentials.
+
+        :param int instance_id: Id of the hardware server
+        """
+        mask = 'mask[credential]'
+        return self.hardware.getAllowedHost(mask=mask, id=instance_id)
+
+    def get_hard_drives(self, instance_id):
+        """Returns the hardware server hard drives.
+
+        :param int instance_id: Id of the hardware server
+        """
+        return self.hardware.getHardDrives(id=instance_id)
 
 
 def _get_extra_price_id(items, key_name, hourly, location):
@@ -717,7 +744,7 @@ def _get_extra_price_id(items, key_name, hourly, location):
 
             return price['id']
 
-    raise SoftLayer.SoftLayerError(
+    raise SoftLayerError(
         "Could not find valid price for extra option, '%s'" % key_name)
 
 
@@ -735,7 +762,7 @@ def _get_default_price_id(items, option, hourly, location):
                     _matches_location(price, location)]):
                 return price['id']
 
-    raise SoftLayer.SoftLayerError(
+    raise SoftLayerError(
         "Could not find valid price for '%s' option" % option)
 
 
@@ -765,7 +792,7 @@ def _get_bandwidth_price_id(items,
 
             return price['id']
 
-    raise SoftLayer.SoftLayerError(
+    raise SoftLayerError(
         "Could not find valid price for bandwidth option")
 
 
@@ -773,11 +800,8 @@ def _get_os_price_id(items, os, location):
     """Returns the price id matching."""
 
     for item in items:
-        if any([utils.lookup(item,
-                             'itemCategory',
-                             'categoryCode') != 'os',
-                utils.lookup(item,
-                             'keyName') != os]):
+        if any([utils.lookup(item, 'itemCategory', 'categoryCode') != 'os',
+                utils.lookup(item, 'keyName') != os]):
             continue
 
         for price in item['prices']:
@@ -786,17 +810,14 @@ def _get_os_price_id(items, os, location):
 
             return price['id']
 
-    raise SoftLayer.SoftLayerError("Could not find valid price for os: '%s'" %
-                                   os)
+    raise SoftLayerError("Could not find valid price for os: '%s'" % os)
 
 
 def _get_port_speed_price_id(items, port_speed, no_public, location):
     """Choose a valid price id for port speed."""
 
     for item in items:
-        if utils.lookup(item,
-                        'itemCategory',
-                        'categoryCode') != 'port_speed':
+        if utils.lookup(item, 'itemCategory', 'categoryCode') != 'port_speed':
             continue
 
         # Check for correct capacity and if the item matches private only
@@ -811,7 +832,7 @@ def _get_port_speed_price_id(items, port_speed, no_public, location):
 
             return price['id']
 
-    raise SoftLayer.SoftLayerError(
+    raise SoftLayerError(
         "Could not find valid price for port speed: '%s'" % port_speed)
 
 
@@ -860,7 +881,7 @@ def _get_location(package, location):
         if region['location']['location']['name'] == location:
             return region
 
-    raise SoftLayer.SoftLayerError("Could not find valid location for: '%s'" % location)
+    raise SoftLayerError("Could not find valid location for: '%s'" % location)
 
 
 def _get_preset_id(package, size):
@@ -869,4 +890,4 @@ def _get_preset_id(package, size):
         if preset['keyName'] == size or preset['id'] == size:
             return preset['id']
 
-    raise SoftLayer.SoftLayerError("Could not find valid size for: '%s'" % size)
+    raise SoftLayerError("Could not find valid size for: '%s'" % size)
