@@ -12,6 +12,7 @@ import mock
 from SoftLayer.CLI import exceptions
 from SoftLayer.fixtures import SoftLayer_Virtual_Guest as SoftLayer_Virtual_Guest
 from SoftLayer import SoftLayerAPIError
+from SoftLayer import SoftLayerError
 from SoftLayer import testing
 
 
@@ -204,6 +205,67 @@ class VirtTests(testing.TestCase):
             ['example-tag'],
         )
 
+    def test_detail_vs_empty_allotment(self):
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getBandwidthAllotmentDetail')
+        mock.return_value = None
+        result = self.run_command(['vs', 'detail', '100'])
+
+        self.assert_no_fail(result)
+        self.assertEqual(
+            json.loads(result.output)['Bandwidth'][0]['Allotment'],
+            '-',
+        )
+
+    def test_detail_drives_system(self):
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getBlockDevices')
+        mock.return_value = [
+            {
+                "createDate": "2018-10-06T04:27:35-06:00",
+                "device": "0",
+                "id": 11111,
+                "mountType": "Disk",
+                "diskImage": {
+                    "capacity": 100,
+                    "description": "adns.vmware.com",
+                    "id": 72222,
+                    "name": "adns.vmware.com",
+                    "units": "GB",
+                }
+            }
+        ]
+        result = self.run_command(['vs', 'detail', '100'])
+
+        self.assert_no_fail(result)
+        output = json.loads(result.output)
+        self.assertEqual(output['drives'][0]['Capacity'], '100 GB')
+        self.assertEqual(output['drives'][0]['Name'], 'Disk')
+        self.assertEqual(output['drives'][0]['Type'], 'System')
+
+    def test_detail_drives_swap(self):
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getBlockDevices')
+        mock.return_value = [
+            {
+                "device": "1",
+                "id": 22222,
+                "mountType": "Disk",
+                "statusId": 1,
+                "diskImage": {
+                    "capacity": 2,
+                    "description": "6211111-SWAP",
+                    "id": 33333,
+                    "name": "6211111-SWAP",
+                    "units": "GB",
+                }
+            }
+        ]
+        result = self.run_command(['vs', 'detail', '100'])
+
+        self.assert_no_fail(result)
+        output = json.loads(result.output)
+        self.assertEqual(output['drives'][0]['Capacity'], '2 GB')
+        self.assertEqual(output['drives'][0]['Name'], 'Disk')
+        self.assertEqual(output['drives'][0]['Type'], 'Swap')
+
     def test_detail_vs_dedicated_host_not_found(self):
         ex = SoftLayerAPIError('SoftLayer_Exception', 'Not found')
         mock = self.set_mock('SoftLayer_Virtual_DedicatedHost', 'getObject')
@@ -308,19 +370,19 @@ class VirtTests(testing.TestCase):
                                            'getResourceRecords')
         getResourceRecords.return_value = []
         createAargs = ({
-            'type': 'a',
-            'host': 'vs-test1',
-            'domainId': 98765,
-            'data': '172.16.240.2',
-            'ttl': 7200
-        },)
+                           'type': 'a',
+                           'host': 'vs-test1',
+                           'domainId': 12345,  # from SoftLayer_Account::getDomains
+                           'data': '172.16.240.2',
+                           'ttl': 7200
+                       },)
         createPTRargs = ({
-            'type': 'ptr',
-            'host': '2',
-            'domainId': 123456,
-            'data': 'vs-test1.test.sftlyr.ws',
-            'ttl': 7200
-        },)
+                             'type': 'ptr',
+                             'host': '2',
+                             'domainId': 123456,
+                             'data': 'vs-test1.test.sftlyr.ws',
+                             'ttl': 7200
+                         },)
 
         result = self.run_command(['vs', 'dns-sync', '100'])
 
@@ -363,12 +425,12 @@ class VirtTests(testing.TestCase):
             }
         }
         createV6args = ({
-            'type': 'aaaa',
-            'host': 'vs-test1',
-            'domainId': 98765,
-            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
-            'ttl': 7200
-        },)
+                            'type': 'aaaa',
+                            'host': 'vs-test1',
+                            'domainId': 12345,
+                            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
+                            'ttl': 7200
+                        },)
         guest.return_value = test_guest
         result = self.run_command(['vs', 'dns-sync', '--aaaa-record', '100'])
         self.assert_no_fail(result)
@@ -398,8 +460,8 @@ class VirtTests(testing.TestCase):
                                            'getResourceRecords')
         getResourceRecords.return_value = [v6Record, v6Record]
         result = self.run_command(['vs', 'dns-sync', '--aaaa-record', '100'])
-        self.assertEqual(result.exit_code, 2)
-        self.assertIsInstance(result.exception, exceptions.CLIAbort)
+        self.assertEqual(result.exit_code, 1)
+        self.assertIsInstance(result.exception, SoftLayerError)
 
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_dns_sync_edit_a(self, confirm_mock):
@@ -429,8 +491,8 @@ class VirtTests(testing.TestCase):
              'host': 'vs-test1', 'type': 'a'}
         ]
         result = self.run_command(['vs', 'dns-sync', '-a', '100'])
-        self.assertEqual(result.exit_code, 2)
-        self.assertIsInstance(result.exception, exceptions.CLIAbort)
+        self.assertEqual(result.exit_code, 1)
+        self.assertIsInstance(result.exception, SoftLayerError)
 
     @mock.patch('SoftLayer.CLI.formatting.confirm')
     def test_dns_sync_edit_ptr(self, confirm_mock):
@@ -728,3 +790,28 @@ class VirtTests(testing.TestCase):
         self.assertEqual(output_summary[1]['Max Date'], date)
         self.assertEqual(output_summary[2]['Max GB'], 0.1172)
         self.assertEqual(output_summary[3]['Sum GB'], 0.0009)
+
+    def test_vs_storage(self):
+        result = self.run_command(
+            ['vs', 'storage', '100'])
+
+        self.assert_no_fail(result)
+
+    def test_billing(self):
+        result = self.run_command(['vs', 'billing', '123456'])
+        vir_billing = {
+            'Billing Item Id': 6327,
+            'Id': '123456',
+            'Provision Date': None,
+            'Recurring Fee': None,
+            'Total': 1.54,
+            'prices': [
+                {'Recurring Price': 1},
+                {'Recurring Price': 1},
+                {'Recurring Price': 1},
+                {'Recurring Price': 1},
+                {'Recurring Price': 1}
+            ]
+        }
+        self.assert_no_fail(result)
+        self.assertEqual(json.loads(result.output), vir_billing)
